import { decorate as _decorate } from './_virtual/_rollupPluginBabelHelpers.js';
import { LitElement, property, html } from 'lit-element';
import style from './fc-text-highlight.css';

/**
 * An element by Forter
 * <!-- Author: Omer Anati <omer.anati@forter.com> -->
 *
 * ## Usage
 *
 * ```html
 * <script>
 *   import '@forter/text-highlight';
 * </script>
 *
 * <fc-text-highlight text="omerikikoo" highlight="ik">
 * </fc-text-highlight>
 * ```
 *
 * @element fc-text-highlight
 * @cssprop --fc-text-highlight-font-weight - font weight.
 * @cssprop --fc-text-highlight-letter-spacing - letter spacing.
 * @cssprop --fc-text-highlight-font-color - color.
 * @cssprop --fc-text-highlight-unhighlighted-font-weight - highlight font weight.
 * @cssprop --fc-text-highlight-unhighlighted-font-color - highlight font color.
 */

let FcTextHighlight = _decorate(null, function (_initialize, _LitElement) {
  class FcTextHighlight extends _LitElement {
    constructor(...args) {
      super(...args);

      _initialize(this);
    }

  }

  return {
    F: FcTextHighlight,
    d: [{
      kind: "field",
      decorators: [property({
        type: String
      })],
      key: "text",

      value() {
        return '';
      }

    }, {
      kind: "field",
      decorators: [property({
        type: String
      })],
      key: "highlight",

      value() {
        return '';
      }

    }, {
      kind: "field",
      static: true,
      key: "is",

      value() {
        return 'fc-text-highlight';
      }

    }, {
      kind: "field",
      static: true,
      key: "styles",

      value() {
        return [style];
      }

    }, {
      kind: "method",
      key: "getHighlightedText",
      value:
      /**
       * The text to display
       * @type {String}
       * @attr
       */

      /**
       * The text to highlight
       * @type {string}
       * @attr
       */

      /** @inheritdoc */

      /** @inheritdoc */

      /**
       * Returns an html with the text, after wrapping the highlight part with bold.
       * @return {*}
       */
      function getHighlightedText() {
        const {
          text,
          highlight
        } = this;
        const index = text.toLowerCase().indexOf(highlight.toLowerCase());

        if (index === -1) {
          return text;
        }

        return html`
      ${text.substring(0, index)}
      <b>${text.substring(index, index + highlight.length)}</b>
      ${text.substring(index + highlight.length, text.length)}`;
      }
      /** @inheritdoc */

    }, {
      kind: "method",
      key: "render",
      value: function render() {
        const {
          text,
          highlight
        } = this;

        if (!highlight) {
          return html`<span>${text}</span>`;
        }

        return html`<div>${this.getHighlightedText()}</div>`;
      }
    }]
  };
}, LitElement);

export { FcTextHighlight };
//# sourceMappingURL=FcTextHighlight.js.map
