import { LitElement, html, property } from 'lit-element';

import style from './fc-text-highlight.css';

/**
 * An element by Forter
 * <!-- Author: Omer Anati <omer.anati@forter.com> -->
 *
 * ## Usage
 *
 * ```html
 * <script>
 *   import '@forter/text-highlight';
 * </script>
 *
 * <fc-text-highlight text="omerikikoo" highlight="ik">
 * </fc-text-highlight>
 * ```
 *
 * @element fc-text-highlight
 * @cssprop --fc-text-highlight-font-weight - font weight.
 * @cssprop --fc-text-highlight-letter-spacing - letter spacing.
 * @cssprop --fc-text-highlight-font-color - color.
 * @cssprop --fc-text-highlight-unhighlighted-font-weight - highlight font weight.
 * @cssprop --fc-text-highlight-unhighlighted-font-color - highlight font color.
 */
export class FcTextHighlight extends LitElement {
  /**
   * The text to display
   * @type {String}
   * @attr
   */
  @property({ type: String }) text = '';

  /**
   * The text to highlight
   * @type {string}
   * @attr
   */
  @property({ type: String }) highlight = '';

  /** @inheritdoc */
  static is = 'fc-text-highlight';

  /** @inheritdoc */
  static styles = [style];

  /**
   * Returns an html with the text, after wrapping the highlight part with bold.
   * @return {*}
   */
  getHighlightedText() {
    const { text, highlight } = this;

    const index = text.toLowerCase().indexOf(highlight.toLowerCase());

    if (index === -1) {
      return text;
    }

    return html`
      ${text.substring(0, index)}
      <b>${text.substring(index, index + highlight.length)}</b>
      ${text.substring(index + highlight.length, text.length)}`;
  }

  /** @inheritdoc */
  render() {
    const { text, highlight } = this;

    if (!highlight) {
      return html`<span>${text}</span>`;
    }

    return html`<div>${this.getHighlightedText()}</div>`;
  }
}
